@@ -1,4 +1,4 @@
-# Copyright (C) 2021,2022 Kian-Meng Ang
+# Copyright (C) 2021,2022,2023 Kian-Meng Ang
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -21,7 +21,7 @@ import sys
 
 logger = logging.getLogger(__name__)
 
-__version__ = "0.1.15"
+__version__ = "0.1.24"
 
 
 def setup_logger(config: argparse.Namespace) -> None:
@@ -41,3 +41,16 @@ def setup_logger(config: argparse.Namespace) -> None:
         format=logformat[config.debug],
         datefmt="%Y-%m-%d %H:%M:%S",
     )
+
+
+def log_or_raise_on_warning(msg: str, raise_on_warning: bool = False) -> None:
+    """Log warnings or raise it as exception.
+
+    Args:
+        msg(str): Warning message.
+        raise_on_warning(bool): To raise exception instead of logging.
+    """
+    if raise_on_warning:
+        raise Exception(msg)
+
+    logger.warning(msg)
