@@ -1,4 +1,4 @@
-# Copyright (C) 2021,2022 Kian-Meng Ang
+# Copyright (C) 2021,2022,2023 Kian-Meng Ang
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -26,10 +26,22 @@ from txt2ebook.models import Book
 
 
 def create_format(
-    book: txt2ebook.models.book.Book, config: argparse.Namespace
+    book: txt2ebook.models.book.Book,
+    ebook_format: str,
+    config: argparse.Namespace,
 ) -> Union[TxtWriter, EpubWriter]:
-    """Create ebook formatter by format using factory function."""
-    class_name = to_classname(config.format, "Writer")
+    """Create ebook formatter by format using factory function.
+
+    Args:
+        book(txt2ebook.models.book.Book): The book model which contains
+        metadata and table of contents of volumes and chapters.
+        ebook_format(str): The ebook format.
+        config(argparse.Namespace): The configs from the command-line.
+
+    Returns:
+        TxtWriter | EpubWriter
+    """
+    class_name = to_classname(ebook_format, "Writer")
     klass = load_class("txt2ebook.formats", class_name)
     formatter = klass(book, config)
     return formatter
