@@ -1,4 +1,4 @@
-# Copyright (C) 2021,2022 Kian-Meng Ang
+# Copyright (C) 2021,2022,2023 Kian-Meng Ang
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -15,6 +15,7 @@
 
 """Convert source text file into EPUB format."""
 
+import gettext
 import io
 import logging
 import uuid
@@ -48,6 +49,7 @@ class EpubWriter:
         """
         self.book = book
         self.config = config
+        self._ = self._load_translation()
 
     def __getattr__(self, key: str) -> Optional[Union[str, bool]]:
         """Get a value of the config based on key name.
@@ -62,11 +64,19 @@ class EpubWriter:
         if hasattr(self.config, key):
             return getattr(self.config, key)
 
-        raise AttributeError(key)
+        raise AttributeError(f"invalid config key: '{key}'!")
+
+    def _load_translation(self):
+        localedir = Path(Path(__file__).parent.parent, "locales")
+        translation = gettext.translation(
+            "txt2ebook", localedir=localedir, languages=[self.config.language]
+        )
+        return translation.gettext
 
     def write(self) -> None:
         """Generate the epub file."""
         book = epub.EpubBook()
+        book.set_identifier(self._gen_id())
 
         if self.book.title:
             book.set_title(self.book.title)
@@ -161,13 +171,13 @@ class EpubWriter:
 
         if self.output_file:
             filename = str(self.output_file)
-        elif self.book.title:
-            filename = self.book.title
         elif isinstance(
             self.input_file, (io.TextIOWrapper, io.BufferedReader)
         ):
             if self.input_file.name != "<stdin>":
                 filename = self.input_file.name
+        elif self.book.title:
+            filename = self.book.title
 
         file = Path(filename)
         return Path(file.parent, file.stem).with_suffix(".epub")
@@ -180,7 +190,7 @@ class EpubWriter:
             </div>
         """
         cover = epub.EpubHtml(
-            title=self.book.structure_names["cover"],
+            title=self._("cover"),
             file_name="cover.xhtml",
             lang=self.book.language,
             content=html,
