@@ -1,5 +1,5 @@
 # pylint: disable=no-value-for-parameter
-# Copyright (C) 2021,2022 Kian-Meng Ang
+# Copyright (C) 2021,2022,2023 Kian-Meng Ang
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -27,7 +27,6 @@ from langdetect import detect
 from txt2ebook import __version__, setup_logger
 from txt2ebook.exceptions import EmptyFileError
 from txt2ebook.formats import create_format
-from txt2ebook.models import Volume
 from txt2ebook.parser import Parser
 
 EBOOK_EXTS = ["epub", "txt"]
@@ -48,31 +47,32 @@ def run(config: argparse.Namespace) -> None:
     if not content:
         raise EmptyFileError(f"Empty file content in {config.input_file.name}")
 
-    config.language = config.language or detect(content)
-    logger.info("Detect language: %s", config.language)
+    config_language = config.language
+    detect_language = detect(content)
+    config.language = config_language or detect_language
+    logger.info("Config language: %s", config_language)
+    logger.info("Detect language: %s", detect_language)
+
+    if config_language and config_language != detect_language:
+        logger.warning(
+            "Config (%s) and detect (%s) language mismatch",
+            config_language,
+            detect_language,
+        )
 
     parser = Parser(content, config)
     book = parser.parse()
 
     if config.test_parsing or config.debug:
-        logger.debug(repr(book))
-        for section in book.toc:
-            logger.debug(repr(section))
-            if isinstance(section, Volume):
-                for chapter in section.chapters:
-                    logger.debug(repr(chapter))
+        book.debug(config.verbose)
 
     if not config.test_parsing:
         if book.toc:
-            writer = create_format(book, config)
-            writer.write()
-
-        # We write to txt for debugging purpose if output format is not
-        # txt.
-        if config.format != "txt":
-            config.format = "txt"
-            txt_writer = create_format(book, config)
-            txt_writer.write()
+            for ebook_format in config.format:
+                writer = create_format(book, ebook_format, config)
+                writer.write()
+        else:
+            logger.warning("No table of content found, not exporting")
 
 
 def build_parser(
@@ -84,7 +84,9 @@ def build_parser(
     parser = argparse.ArgumentParser(
         add_help=False,
         description=_doc(),
-        formatter_class=argparse.RawTextHelpFormatter,
+        formatter_class=lambda prog: argparse.RawTextHelpFormatter(
+            prog, max_help_position=6
+        ),
     )
 
     parser.add_argument(
@@ -109,14 +111,17 @@ def build_parser(
 
     parser.add_argument(
         "-f",
+        "--format",
         dest="format",
-        default="epub",
+        default=["epub", "txt"],
         choices=EBOOK_EXTS,
+        action="append",
         help="ebook format (default: '%(default)s')",
     )
 
     parser.add_argument(
         "-t",
+        "--title",
         dest="title",
         default=None,
         help="title of the ebook (default: '%(default)s')",
@@ -125,6 +130,7 @@ def build_parser(
 
     parser.add_argument(
         "-l",
+        "--language",
         dest="language",
         default=None,
         help="language of the ebook (default: '%(default)s')",
@@ -133,6 +139,7 @@ def build_parser(
 
     parser.add_argument(
         "-a",
+        "--author",
         dest="author",
         default=[],
         action="append",
@@ -142,6 +149,7 @@ def build_parser(
 
     parser.add_argument(
         "-c",
+        "--cover",
         dest="cover",
         default=None,
         help="cover of the ebook",
@@ -150,6 +158,7 @@ def build_parser(
 
     parser.add_argument(
         "-w",
+        "--width",
         dest="width",
         type=int,
         default=None,
@@ -159,8 +168,9 @@ def build_parser(
 
     parser.add_argument(
         "-ps",
+        "--paragraph_separator",
         dest="paragraph_separator",
-        type=str,
+        type=lambda value: value.encode("utf-8").decode("unicode_escape"),
         default="\n\n",
         help="paragraph separator (default: %(default)r)",
         metavar="SEPARATOR",
@@ -168,6 +178,7 @@ def build_parser(
 
     parser.add_argument(
         "-rd",
+        "--regex-delete",
         dest="re_delete",
         default=[],
         action="append",
@@ -177,6 +188,7 @@ def build_parser(
 
     parser.add_argument(
         "-rvc",
+        "--regex-volume-chapter",
         dest="re_volume_chapter",
         default=[],
         action="append",
@@ -189,6 +201,7 @@ def build_parser(
 
     parser.add_argument(
         "-rv",
+        "--regex-volume",
         dest="re_volume",
         default=[],
         action="append",
@@ -198,6 +211,7 @@ def build_parser(
 
     parser.add_argument(
         "-rc",
+        "--regex-chapter",
         dest="re_chapter",
         default=[],
         action="append",
@@ -207,6 +221,7 @@ def build_parser(
 
     parser.add_argument(
         "-rt",
+        "--regex-title",
         dest="re_title",
         default=[],
         action="append",
@@ -216,6 +231,7 @@ def build_parser(
 
     parser.add_argument(
         "-ra",
+        "--regex-author",
         dest="re_author",
         default=[],
         action="append",
@@ -225,6 +241,7 @@ def build_parser(
 
     parser.add_argument(
         "-rl",
+        "--regex-delete-line",
         dest="re_delete_line",
         default=[],
         action="append",
@@ -234,6 +251,7 @@ def build_parser(
 
     parser.add_argument(
         "-rr",
+        "--regex-replace",
         dest="re_replace",
         nargs=2,
         default=[],
@@ -244,6 +262,7 @@ def build_parser(
 
     parser.add_argument(
         "-et",
+        "--epub-template",
         default="clean",
         dest="epub_template",
         help="CSS template for epub ebook (default: '%(default)s')",
@@ -256,7 +275,7 @@ def build_parser(
         default=False,
         action="store_true",
         dest="volume_page",
-        help="generate each volume as separate page",
+        help="generate each volume as separate page (only 'epub' format)",
     )
 
     parser.add_argument(
@@ -269,12 +288,75 @@ def build_parser(
     )
 
     parser.add_argument(
-        "-nb",
-        "--no-backup",
+        "-sp",
+        "--split-volume-and-chapter",
         default=False,
         action="store_true",
-        dest="no_backup",
-        help="disable backup source TXT_FILENAME",
+        dest="split_volume_and_chapter",
+        help=(
+            "Split volume or chapter into separate file (only 'txt' format).\n"
+            "Both --overwrite-backup and --overwrite option will be ignore."
+        ),
+    )
+
+    parser.add_argument(
+        "-hn",
+        "--header-number",
+        default=False,
+        action="store_true",
+        dest="header_number",
+        help=(
+            "convert section header from words to numbers "
+            "(only 'zh-cn/zh-tw' language)"
+        ),
+    )
+
+    parser.add_argument(
+        "-fw",
+        "--fullwidth",
+        default=False,
+        action="store_true",
+        dest="fullwidth",
+        help=(
+            "convert ASCII character from halfwidth to fullwidth "
+            "(only 'zh-cn/zh-tw' language)"
+        ),
+    )
+
+    parser.add_argument(
+        "-rw",
+        "--raise-on-warning",
+        default=False,
+        action="store_true",
+        dest="raise_on_warning",
+        help="raise exception and stop parsing upon warning",
+    )
+
+    parser.add_argument(
+        "-ob",
+        "--overwrite-backup",
+        default=False,
+        action="store_true",
+        dest="overwrite_backup",
+        help="overwrite massaged and backup original TXT_FILENAME",
+    )
+
+    parser.add_argument(
+        "-ow",
+        "--overwrite",
+        default=False,
+        action="store_true",
+        dest="overwrite",
+        help="overwrite massaged TXT_FILENAME",
+    )
+
+    parser.add_argument(
+        "-v",
+        "--verbose",
+        default=0,
+        action="count",
+        dest="verbose",
+        help="show verbosity of debugging log, use -vv, -vvv for more details",
     )
 
     parser.add_argument(
@@ -295,7 +377,7 @@ def build_parser(
     )
 
     parser.add_argument(
-        "-v", "--version", action="version", version=f"%(prog)s {__version__}"
+        "-V", "--version", action="version", version=f"%(prog)s {__version__}"
     )
 
     return parser
